@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
 # «backend» - Backend Manager.  Handles install actions that would require root
@@ -26,7 +26,7 @@
 
 import logging, os, os.path, signal, sys
 
-import gobject
+from gi.repository import GObject
 import dbus
 import dbus.service
 import dbus.mainloop.glib
@@ -79,14 +79,14 @@ def dbus_sync_call_signal_wrapper(dbus_iface, fn, handler_map, *args, **kwargs):
         _h_exception_exc = exception
         loop.quit()
 
-    loop = gobject.MainLoop()
+    loop = GObject.MainLoop()
     global _h_reply_result, _h_exception_exc
     _h_reply_result = None
     _h_exception_exc = None
     kwargs['reply_handler'] = _h_reply
     kwargs['error_handler'] = _h_error
     kwargs['timeout'] = 86400
-    for signame, sighandler in handler_map.iteritems():
+    for signame, sighandler in list(handler_map.items()):
         dbus_iface.connect_to_signal(signame, sighandler)
     dbus_iface.get_dbus_method(fn)(*args, **kwargs)
     loop.run()
@@ -128,13 +128,13 @@ class Backend(dbus.service.Object):
         once the server is ready to take requests.
         '''
         dbus.service.Object.__init__(self, self.bus, '/ControlCentre')
-        main_loop = gobject.MainLoop()
+        main_loop = GObject.MainLoop()
         self._timeout = False
         if timeout:
             def _t():
                 main_loop.quit()
                 return True
-            gobject.timeout_add(timeout * 1000, _t)
+            GObject.timeout_add(timeout * 1000, _t)
 
         # send parent process a signal that we are ready now
         if send_usr1:
@@ -203,7 +203,7 @@ class Backend(dbus.service.Object):
                     ('unix-process', {'pid': dbus.UInt32(pid, variant_level=1),
                      'start-time': dbus.UInt64(0, variant_level=1)}), 
                      privilege, {'': ''}, dbus.UInt32(1), '', timeout=600)
-        except dbus.DBusException, e:
+        except dbus.DBusException as e:
             if e._dbus_error_name == 'org.freedesktop.DBus.Error.ServiceUnknown':
                 # polkitd timed out, connect again
                 self.polkit = None
