@@ -21,7 +21,7 @@
 ##################################################################################
 
 from MythbuntuControlCentre.plugin import MCCPlugin
-import gtk
+from gi.repository import Gtk
 import time
 
 class SkeletonPlugin(MCCPlugin):
@@ -71,7 +71,7 @@ class SkeletonPlugin(MCCPlugin):
     #
     def callback_example(self,widget,data=None):
         """Shows an example of how a callback can do stuff"""
-        widget_was_visible = self.callback_image.flags() & gtk.VISIBLE
+        widget_was_visible = self.callback_image.flags() & Gtk.VISIBLE
         if widget_was_visible:
             self.callback_image.hide()
         else:
